@@ -401,6 +401,9 @@ protected:
     KConfig(KConfigPrivate &d);
 
 private:
+    bool isDirty() const;
+    friend class KConfigTest;
+
     QStringList keyList(const QString& aGroup=QString()) const;
 
     Q_DISABLE_COPY(KConfig)
